@@ -7,12 +7,12 @@ import tarfile
 import datetime
 from enum import Enum, IntEnum
 
-PROJECT_BASE = None
+PROJECT_BASE = os.getenv("FATE_DEPLOY_BASE")
 
 
 def start_cluster_standalone_job_server():
-    print('use service.sh to start standalone node server....')
-    os.system('sh service.sh start --standalone_node')
+    print("use service.sh to start standalone node server....")
+    os.system("sh service.sh start --standalone_node")
     time.sleep(5)
 
 
@@ -24,12 +24,15 @@ def get_project_base_directory():
     global PROJECT_BASE
     if PROJECT_BASE is None:
         PROJECT_BASE = os.path.abspath(
-            os.path.join(os.path.dirname(os.path.realpath(__file__)), os.pardir, os.pardir))
+            os.path.join(
+                os.path.dirname(os.path.realpath(__file__)), os.pardir, os.pardir
+            )
+        )
     return PROJECT_BASE
 
 
 def download_from_request(http_response, tar_file_name, extract_dir):
-    with open(tar_file_name, 'wb') as fw:
+    with open(tar_file_name, "wb") as fw:
         for chunk in http_response.iter_content(1024):
             if chunk:
                 fw.write(chunk)
@@ -55,40 +58,44 @@ def check_config(config: typing.Dict, required_arguments: typing.List):
         elif require_argument not in config:
             no_arguments.append(require_argument)
     if no_arguments or error_arguments:
-        raise Exception('the following arguments are required: {} {}'.format(','.join(no_arguments), ','.join(
-            ['{}={}'.format(a[0], a[1]) for a in error_arguments])))
+        raise Exception(
+            "the following arguments are required: {} {}".format(
+                ",".join(no_arguments),
+                ",".join(["{}={}".format(a[0], a[1]) for a in error_arguments]),
+            )
+        )
 
 
 def preprocess(**kwargs):
     config_data = {}
-    if 'self' in kwargs:
-        kwargs.pop('self')
+    if "self" in kwargs:
+        kwargs.pop("self")
 
-    if kwargs.get('conf_path'):
-        conf_path = os.path.abspath(kwargs.get('conf_path'))
-        with open(conf_path, 'r') as conf_fp:
+    if kwargs.get("conf_path"):
+        conf_path = os.path.abspath(kwargs.get("conf_path"))
+        with open(conf_path, "r") as conf_fp:
             config_data = json.load(conf_fp)
 
-        if config_data.get('output_path'):
-            config_data['output_path'] = os.path.abspath(config_data['output_path'])
+        if config_data.get("output_path"):
+            config_data["output_path"] = os.path.abspath(config_data["output_path"])
 
-        if ('party_id' in kwargs.keys()) or ('role' in kwargs.keys()):
-            config_data['local'] = config_data.get('local', {})
-            if kwargs.get('party_id'):
-                config_data['local']['party_id'] = kwargs.get('party_id')
-            if kwargs.get('role'):
-                config_data['local']['role'] = kwargs.get('role')
+        if ("party_id" in kwargs.keys()) or ("role" in kwargs.keys()):
+            config_data["local"] = config_data.get("local", {})
+            if kwargs.get("party_id"):
+                config_data["local"]["party_id"] = kwargs.get("party_id")
+            if kwargs.get("role"):
+                config_data["local"]["role"] = kwargs.get("role")
 
     config_data.update(dict((k, v) for k, v in kwargs.items() if v is not None))
 
-    for key in ['job_id', 'party_id']:
+    for key in ["job_id", "party_id"]:
         if isinstance(config_data.get(key), int):
             config_data[key] = str(config_data[key])
 
     dsl_data = {}
-    if kwargs.get('dsl_path'):
-        dsl_path = os.path.abspath(kwargs.get('dsl_path'))
-        with open(dsl_path, 'r') as dsl_fp:
+    if kwargs.get("dsl_path"):
+        dsl_path = os.path.abspath(kwargs.get("dsl_path"))
+        with open(dsl_path, "r") as dsl_fp:
             dsl_data = json.load(dsl_fp)
     return config_data, dsl_data
 
@@ -111,7 +118,12 @@ def get_lan_ip():
         def get_interface_ip(ifname):
             s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
             return socket.inet_ntoa(
-                fcntl.ioctl(s.fileno(), 0x8915, struct.pack('256s', string_to_bytes(ifname[:15])))[20:24])
+                fcntl.ioctl(
+                    s.fileno(),
+                    0x8915,
+                    struct.pack("256s", string_to_bytes(ifname[:15])),
+                )[20:24]
+            )
 
     ip = socket.gethostbyname(socket.getfqdn())
     if ip.startswith("127.") and os.name != "nt":
@@ -133,7 +145,7 @@ def get_lan_ip():
                 break
             except IOError as e:
                 pass
-    return ip or ''
+    return ip or ""
 
 
 class CustomJSONEncoder(json.JSONEncoder):
@@ -142,9 +154,9 @@ class CustomJSONEncoder(json.JSONEncoder):
 
     def default(self, obj):
         if isinstance(obj, datetime.datetime):
-            return obj.strftime('%Y-%m-%d %H:%M:%S')
+            return obj.strftime("%Y-%m-%d %H:%M:%S")
         elif isinstance(obj, datetime.date):
-            return obj.strftime('%Y-%m-%d')
+            return obj.strftime("%Y-%m-%d")
         elif isinstance(obj, datetime.timedelta):
             return str(obj)
         elif issubclass(type(obj), Enum) or issubclass(type(obj), IntEnum):
@@ -157,4 +169,4 @@ def json_dumps(src, byte=False, indent=None):
     if byte:
         return string_to_bytes(json.dumps(src, indent=indent, cls=CustomJSONEncoder))
     else:
-        return json.dumps(src, indent=indent, cls=CustomJSONEncoder)
\ No newline at end of file
+        return json.dumps(src, indent=indent, cls=CustomJSONEncoder)
