@@ -14,6 +14,7 @@
 #  limitations under the License.
 #
 import copy
+import getpass
 import json
 import pickle
 import sys
@@ -24,6 +25,7 @@ from pipeline.backend.config import Backend, WorkMode
 from pipeline.backend.config import Role
 from pipeline.backend.config import StatusCode
 from pipeline.backend.config import VERSION
+from pipeline.backend.config import SystemSetting
 from pipeline.backend.task_info import TaskInfo
 from pipeline.component.component_base import Component
 from pipeline.component.reader import Reader
@@ -54,11 +56,13 @@ class PipeLine(object):
         self._fit_status = None
         self._train_board_url = None
         self._model_info = None
+        self._predict_model_info = None
         self._train_components = {}
         self._stage = "fit"
         self._data_to_feed_in_prediction = None
         self._predict_pipeline = []
         self._deploy = False
+        self._system_role = SystemSetting.system_setting().get("role")
 
     @LOGGER.catch(reraise=True)
     def set_initiator(self, role, party_id):
@@ -386,9 +390,26 @@ class PipeLine(object):
                 if not isinstance(val, list):
                     val = [val]
 
+                if "input" not in self._predict_dsl["components"][cpn]:
+                    self._predict_dsl["components"][cpn]["input"] = {}
+
+                if 'data' not in self._predict_dsl["components"][cpn]["input"]:
+                    self._predict_dsl["components"][cpn]["input"]["data"] = {}
+
                 self._predict_dsl["components"][cpn]["input"]["data"][dataset] = val
+
         return self
 
+    @LOGGER.catch(reraise=True)
+    def _check_duplicate_setting(self, submit_conf):
+        system_role = self._system_role
+        if "role" in submit_conf["job_parameters"]:
+            role_conf = submit_conf["job_parameters"]["role"]
+            system_role_conf = role_conf.get(system_role, {})
+            for party, conf in system_role_conf.items():
+                if conf.get("user"):
+                    raise ValueError(f"system role {system_role}'s user info already set. Please check.")
+
     def _feed_job_parameters(self, conf, job_type=None,
                              model_info=None, job_parameters=None):
         submit_conf = copy.deepcopy(conf)
@@ -406,6 +427,20 @@ class PipeLine(object):
             submit_conf["job_parameters"]["common"]["model_id"] = model_info.model_id
             submit_conf["job_parameters"]["common"]["model_version"] = model_info.model_version
 
+        if self._system_role:
+            self._check_duplicate_setting(submit_conf)
+            init_role = self._initiator.role
+            idx = str(self._roles[init_role].index(self._initiator.party_id))
+            if "role" not in submit_conf["job_parameters"]:
+                submit_conf["job_parameters"]["role"] = {}
+
+            if init_role not in submit_conf["job_parameters"]["role"]:
+                submit_conf["job_parameters"]["role"][init_role] = {}
+
+            if idx not in submit_conf["job_parameters"]["role"][init_role]:
+                submit_conf["job_parameters"]["role"][init_role][idx] = {}
+
+            submit_conf["job_parameters"]["role"][init_role][idx].update({"user": getpass.getuser()})
         return submit_conf
 
     def _filter_out_deploy_component(self, predict_conf):
@@ -474,9 +509,14 @@ class PipeLine(object):
 
         self.compile()
 
+        res_dict = self._job_invoker.model_deploy(model_id=self._model_info.model_id,
+                                                  model_version=self._model_info.model_version,
+                                                  predict_dsl=self._predict_dsl)
+        self._predict_model_info = SimpleNamespace(model_id=res_dict["model_id"],
+                                                   model_version=res_dict["model_version"])
         predict_conf = self._feed_job_parameters(self._train_conf,
                                                  job_type="predict",
-                                                 model_info=self._model_info,
+                                                 model_info=self._predict_model_info,
                                                  job_parameters=job_parameters)
         predict_conf = self._filter_out_deploy_component(predict_conf)
         self._predict_conf = copy.deepcopy(predict_conf)
@@ -518,31 +558,33 @@ class PipeLine(object):
             return pickle.loads(fin.read())
 
     @LOGGER.catch(reraise=True)
-    def deploy_component(self, components):
+    def deploy_component(self, components=None):
         if self._train_dsl is None:
             raise ValueError("Before deploy model, training should be finish!!!")
 
-        if not components:
-            deploy_cpns = list(self._components.keys())
-        else:
-            deploy_cpns = []
-            for cpn in components:
-                if isinstance(cpn, str):
-                    deploy_cpns.append(cpn)
-                elif isinstance(cpn, Component):
-                    deploy_cpns.append(cpn.name)
-                else:
-                    raise ValueError(
-                        "deploy component parameters is wrong, expect str or Component object, but {} find".format(cpn))
+        if components is None:
+            components = self._components
+        deploy_cpns = []
+        for cpn in components:
+            if isinstance(cpn, str):
+                deploy_cpns.append(cpn)
+            elif isinstance(cpn, Component):
+                deploy_cpns.append(cpn.name)
+            else:
+                raise ValueError(
+                    "deploy component parameters is wrong, expect str or Component object, but {} find".format(type(cpn)))
 
-                if deploy_cpns[-1] not in self._components:
-                    raise ValueError("Component {} does not exist in pipeline".format(deploy_cpns[-1]))
+            if deploy_cpns[-1] not in self._components:
+                raise ValueError("Component {} does not exist in pipeline".format(deploy_cpns[-1]))
 
-                if isinstance(self._components.get(deploy_cpns[-1]), Reader):
-                    raise ValueError("Reader should not be include in predict pipeline")
+            if isinstance(self._components.get(deploy_cpns[-1]), Reader):
+                raise ValueError("Reader should not be include in predict pipeline")
+        res_dict = self._job_invoker.model_deploy(model_id=self._model_info.model_id,
+                                                  model_version=self._model_info.model_version,
+                                                  cpn_list=deploy_cpns)
 
-        self._predict_dsl = self._job_invoker.get_predict_dsl(train_dsl=self._train_dsl, cpn_list=deploy_cpns,
-                                                              version=VERSION)
+        self._predict_dsl = self._job_invoker.get_predict_dsl(model_id=res_dict["model_id"],
+                                                              model_version=res_dict["model_version"])
 
         if self._predict_dsl:
             self._deploy = True
