@@ -1,6 +1,7 @@
 from pipeline.component.column_expand import ColumnExpand
 from pipeline.component.data_statistics import DataStatistics
 from pipeline.component.dataio import DataIO
+from pipeline.component.data_transform import DataTransform 
 from pipeline.component.evaluation import Evaluation
 from pipeline.component.hetero_data_split import HeteroDataSplit
 from pipeline.component.hetero_fast_secureboost import HeteroFastSecureBoost
@@ -17,6 +18,7 @@ from pipeline.component.homo_data_split import HomoDataSplit
 from pipeline.component.homo_lr import HomoLR
 from pipeline.component.homo_nn import HomoNN
 from pipeline.component.homo_secureboost import HomoSecureBoost
+from pipeline.component.homo_feature_binning import HomoFeatureBinning
 from pipeline.component.intersection import Intersection
 from pipeline.component.local_baseline import LocalBaseline
 from pipeline.component.one_hot_encoder import OneHotEncoder
@@ -26,13 +28,17 @@ from pipeline.component.scorecard import Scorecard
 from pipeline.component.sampler import FederatedSample
 from pipeline.component.scale import FeatureScale
 from pipeline.component.union import Union
+from pipeline.component.feldman_verifiable_sum import FeldmanVerifiableSum
+from pipeline.component.sample_weight import SampleWeight
+from pipeline.component.sbt_feature_transformer import SBTTransformer
 
 
 __all__ = ["DataStatistics", "DataIO", "Evaluation", "HeteroDataSplit",
            "HeteroFastSecureBoost", "HeteroFeatureBinning", "HeteroFeatureSelection",
            "HeteroFTL", "HeteroLinR", "HeteroLR", "HeteroNN",
            "HeteroPearson", "HeteroPoisson", "HeteroSecureBoost", "HomoDataSplit",
-           "HomoLR", "HomoNN", "HomoSecureBoost", "Intersection",
+           "HomoLR", "HomoNN", "HomoSecureBoost", "HomoFeatureBinning", "Intersection",
            "LocalBaseline", "OneHotEncoder", "PSI", "Reader", "Scorecard",
-           "FederatedSample", "FeatureScale", "Union", "ColumnExpand"]
+           "FederatedSample", "FeatureScale", "Union", "ColumnExpand", "FeldmanVerifiableSum",
+           "SampleWeight", "DataTransform", "SBTTransformer"]
 
